/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { IProducer } from "@fluidframework/server-services-core";
import * as kafka from "kafka-node";
/**
 * Kafka producer using the kafka-node library
 * @internal
 */
export declare class KafkaNodeProducer implements IProducer {
    private readonly clientOptions;
    private readonly topic;
    private readonly topicPartitions?;
    private readonly topicReplicationFactor?;
    private readonly messages;
    private client;
    private producer;
    private sendPending?;
    private readonly events;
    private connecting;
    private connected;
    private readonly maxBatchSize;
    private readonly maxMessageSize;
    constructor(clientOptions: kafka.KafkaClientOptions, clientId: string, topic: string, topicPartitions?: number | undefined, topicReplicationFactor?: number | undefined, maxBatchSize?: number, maxMessageSize?: number);
    isConnected(): boolean;
    /**
     * Sends the provided message to Kafka
     */
    send(messages: object[], tenantId: string, documentId: string): Promise<any>;
    close(): Promise<void>;
    on(event: "connected" | "produced" | "error", listener: (...args: any[]) => void): this;
    once(event: "connected" | "produced" | "error", listener: (...args: any[]) => void): this;
    off(event: "connected" | "produced" | "error", listener: (...args: any[]) => void): this;
    /**
     * Notifies of the need to send pending messages. We defer sending messages to batch together messages
     * to the same partition.
     */
    private requestSend;
    /**
     * Sends all pending messages
     */
    private sendPendingMessages;
    private sendBoxcars;
    /**
     * Creates a connection to Kafka. Will reconnect on failure.
     */
    private connect;
    /**
     * Handles an error that requires a reconnect to Kafka
     */
    private handleError;
}
//# sourceMappingURL=kafkaNodeProducer.d.ts.map